import { ActionType } from './action';
import { ICommonStyle } from './style';
import { IWeAppCode } from './lowcode';
import { IPlugin } from './plugins';
import { PropBindType, IEventModifiers, IWeAppComponentInstance } from './app';
import { IDataSourceQuery, IPlatformDataset, IStateVariable, IDataSourceVariable, IDataVarMethod } from '@cloudbase/cals';
export interface IRuntimeQuery extends Omit<IDataSourceQuery, 'handler' | 'dataSourceName' | 'method' | 'listeners'> {
    handler: {
        moduleName: string;
        name: string;
    };
    data: any;
    dataBinds: IDataBind[];
    dataTypes: IDataType[];
    listenerInstances: IListenerInstance[];
}
interface IRuntimeDataVarMethod extends Omit<IDataVarMethod, 'params'> {
    params: Object;
    paramsBinds?: IDataBind[];
}
interface IRuntimeDatasourceVariable extends Omit<IDataSourceVariable, 'initMethod' | 'updateMethod'> {
    /**
     * 变量初始化的方法, 集合/单条记录类型变量需有该方法
     */
    initMethod?: IRuntimeDataVarMethod;
    /**
     * 变量更新时候的方法, 新纪录/单条记录·编辑类型需有该方法
     */
    updateMethod?: IRuntimeDataVarMethod;
}
interface IRuntimeDataset {
    /** 各种变量 */
    dataset?: {
        /** 状态 */
        state?: Record<string, IStateVariable | IRuntimeDatasourceVariable>;
        /** 页面/应用 参数 */
        params?: IPlatformDataset['params'];
        query?: Record<string, IRuntimeQuery>;
    };
    vars: {
        /** 数据源变量 */
        data: any[];
    };
}
export interface IWebRuntimeAppData extends IRuntimeDataset {
    label?: string;
    description?: string;
    /**
     * 云开发环境envId
     */
    envId?: string;
    /**
     * 数据源
     */
    datasources: any[];
    selectedPageId?: string;
    pageInstanceList: IPageInstance[];
    rootPath?: string;
    maxID?: number;
    codeModules: IWeAppCode[];
    /**
     * The dependency in package.json of generated app
     */
    npmDependencies: {
        [packageName: string]: string;
    };
    plugins?: IPlugin[];
    themeVars?: {
        [key: string]: string;
    };
    presetColors?: string[];
    appConfig?: {
        [key: string]: any;
    };
    extra: {
        domain: string;
        clientId?: string;
        loginConfigVersion?: string;
        enableLoading?: string;
        favicon?: string;
    };
    conditionalRendering?: string;
}
export interface IPageInstance extends ICommonInstanceProps, IRuntimeDataset {
    id: string;
    isHome?: boolean;
    componentSchemaJson?: IComponentSchemaJson;
    pluginInstances: IPluginInstance[];
    children?: IPageInstance[];
    codeModules: IWeAppCode[];
}
export interface IPageData {
    title: string;
    desc?: string;
}
export interface IDataBind {
    propertyPath: string;
    bindDataPath: string;
    type?: PropBindType;
}
export interface IDataType {
    propertyPath: string;
    type?: 'static' | 'slot' | 'bind';
}
export interface IDataAndBindInstanceProps {
    data: {
        [key: string]: any;
    };
    dataBinds?: IDataBind[];
    dataTypes?: IDataType[];
}
export interface IItemInstance extends IDataAndBindInstanceProps {
    key: Readonly<string>;
    sourceKey: string;
    instanceFunction?: string;
}
export interface IPluginInstance extends IItemInstance {
    instanceFunction?: string;
}
export interface IListenerInstance extends IItemInstance, IEventModifiers {
    trigger: string;
    target?: string | null;
    type: ActionType;
    handler?: {
        moduleName: string;
        name: string;
    };
    jsCode?: string;
}
export interface IComponentSchemaJson {
    key?: string;
    type?: string;
    ['x-component']?: string;
    ['x-props']?: IComponentInstanceProps;
    ['x-index']?: number;
    properties: {
        [key: string]: IComponentSchemaJson;
    };
    path?: string;
    /**
     * 用于组件开发，将当前组件设为抽象组件（用户在使用时可指定其他组件代替改组件）
     * https://developers.weixin.qq.com/miniprogram/dev/framework/custom-component/generics.html
     */
    genericComp?: IWeAppComponentInstance['genericComp'];
}
export interface ICommonInstanceProps extends IDataAndBindInstanceProps {
    style: object;
    commonStyle?: ICommonStyle;
    styleBindPath?: string;
    styleBind?: IDataBind;
    classNameListBind?: IDataBind;
    classNameList?: string[];
    listenerInstances: IListenerInstance[];
    customDataForm?: Record<string, any>;
    staticResourceAttribute?: string[];
}
export interface IComponentInstanceProps extends ICommonInstanceProps {
    sourceKey: string;
    isContainer: boolean;
}
export interface IPageWidgets {
    style: Record<string, any>;
    classList: string[];
    value?: any;
    [key: string]: any;
}
export interface II18nConfig {
    enabled: boolean;
    i18nData: any;
    baseUrl?: string;
    docUrl?: string;
}
export interface IExtraData {
    isComposite: boolean;
    compProps: any;
}
export {};
