import * as React from 'react';
import { WedaApp, isEnableWecom} from '@cloudbase/lowcode-render';
import { default as data, dependencies } from './data';
import config from '../datasources/config';
import { loadDependencies } from '../utils/adapter/dependencies';
import lowcodeModulesMap from '../lowcode/index'

const STATUS_STYLE = `.weda-loading-container {
  position: fixed;
  left:0;
  top:0;
  width: 100%;
  display: flex;
  justify-content: center;
  align-items: center;
  flex-direction: column;
  height:100%;
  padding: 0 20px;
}
.weda-loading-container .logo {
  width: 100%;
  display: flex;
  justify-content: center;
  text-align: center;
  margin-bottom: 50px;
}

.weda-loading-container .sp{
  width: 48px;
  height:48px;
}

.weda-loading-container .sp-circle {
  border: 6px rgba(0,82,217,0.25) solid;
  border-top: 6px rgba(0,82,217,1) solid;
  border-radius: 50%;
  -webkit-animation: spCircRot .6s infinite linear;
  animation: spCircRot .6s infinite linear;
}
@-webkit-keyframes spCircRot {
  from { -webkit-transform: rotate(0deg); }
  to { -webkit-transform: rotate(359deg); }
}
@keyframes spCircRot {
  from { transform: rotate(0deg); }
  to { transform: rotate(359deg); }
}`;

function Loading({message="数据加载中..."}) {
  const [show, setShow] = React.useState(false)
  React.useEffect(()=>{
    const enableWecom = isEnableWecom(data?.extra?.envId||data?.envId)
    const enableLoading = data?.extra?.enableLoading === undefined ? enableWecom : data?.extra?.enableLoading
    if(enableLoading){
      setTimeout(()=>{
        setShow(true)
      }, 100)
    }
  }, [])
  return (
    <>
      <style
        type="text/css"
        dangerouslySetInnerHTML={{
          __html: STATUS_STYLE,
        }}
      />
      {show && <div className="weda-loading-container">
        <div className="logo">
          <div className="sp sp-circle"></div>
        </div>
        <div className="text">
          {message === '正在加载组件、编译代码...' ? "登录鉴权中...": message}
        </div>
      </div>}
    </>
  );
}

export default function App() {
  return (
    <WedaApp
      cals={data}
      dependencies={dependencies}
      historyOption={{
        type:
          process.env.historyType === 'HASH'
            ? 'HASH'
            : 'BROWSER',
        basename: '<%= basename %>',
        _indexPage: <%= context.history._indexPage ? 'true': 'false' %>
      }}
      _processDependencies={(deps)=>{
        return deps
      }}
      loadDependencies={loadDependencies}
      loadLowcodes={async (cals) => {
        return lowcodeModulesMap
      }}
      loadExternalResources={async ()=>null}
      context={{
        basic: <%= context.basic ? 'true': 'false' %>,
        getDatasourceConfig: () => {
          return config;
        },
        checkPageAuth: <%= context.checkPageAuth %>
      }}
      ErrorBoundary={React.Fragment}
      renderLoading={({message})=><Loading message={message} />}
    ></WedaApp>
  );
}
